@@ -363,7 +363,7 @@ void make_new_cf_config( std::string name,
 {
     std::ofstream f(name.c_str());
     f << "# cproxy config file\n\n";
-    f << "# Created by the unit test for fileter_cproxy\n";
+    f << "# Created by the unit test for filter_cproxy\n";
     f << "# Should have been deleted at the end of the tests\n\n";
     if(!http.empty())
         f << "httpproxyprefix: " << http << "\n";
@@ -505,6 +505,30 @@ void test0(void)
         YAZ_CHECK ("got an exception as expected" );
     }
 
+    // A cf-config file with a good proxyprefix, including a port number
+    make_cf_config("./cf-config.unittest.cfg", // config file to write
+                   "localhost:987/XXX/node102",
+                   ".", // session directory
+                   "" );  // no cf-zserver
+    try {
+        mp::filter::CProxy *good_cpx = make_filter( conf );
+    }
+    catch (std::exception & e) {
+        YAZ_CHECK (!"Exception parsing config file" );
+    }
+
+    // A cf-config file with a good proxyprefix
+    make_cf_config("./cf-config.unittest.cfg", // config file to write
+                   "localhost/XXX/node102",
+                   ".", // session directory
+                   "" );  // no cf-zserver
+    try {
+        mp::filter::CProxy *good_cpx = make_filter( conf );
+    }
+    catch (std::exception & e) {
+        YAZ_CHECK (!"Exception parsing config file" );
+    }
+
     // A cf-config file with a bad proxy prefix (all numerical component)
     // Those will get confused with the session number, so they are disallowed
     // (actually, filter_cproxy will handle the just fine, but later a
@@ -585,10 +609,17 @@ void test1(void)
 
 
     //
-    make_cf_config("./cf-config.unittest.cfg", // config file to write
+    // A new-style cf-config file with conflicting proxy prefixes
+    make_new_cf_config("./cf-config.unittest.cfg", // config file to write
+                  "", //"http://localhost:9036/XXX/node102",
+                  "https://localhost:9036/XXX/node102",
+                   ".", // session directory
+                   "" );  // no cf-zserver for content connectors, in this test
+/*    make_cf_config("./cf-config.unittest.cfg", // config file to write
                    "localhost:9036/XXX/node102",  // url prefix
                    ".", // session directory
-                   "" );  // cf-zserver for content connectors, "localhost:9001"
+                   "" );  // no cf-zserver for content connectors
+*/
     mp::filter::CProxy *cpx = make_filter( conf );
     mp::Package *pack;
 
@@ -886,13 +917,27 @@ void test1(void)
                "path/to/page.txt",1);
     // Must have the content-bit (8) in debug, or we fake a regular OK response
     add_request_header(pack, "Cookie",
-                "name1=value1;cproxysession=fakehost.com/100 ; name3=value3");
+                "name1=value1;cproxysession=https/fakehost.com/100 ; name3=value3");
     cpx->process(*pack);
 
     YAZ_CHECK( check_response_code(pack, 302) );
     YAZ_CHECK( check_response_header(pack, "Location",
-          "http://localhost:9036/XXX/node102/100/"
-          "fakehost.com/path/to/page.txt") );
+          "https://localhost:9036/XXX/node102/100/"
+          "https/fakehost.com/path/to/page.txt") );
+    delete(pack);
+
+    // No referer header, fall back to a cproxy session cookie. With port number in the cookie
+    pack = make_package("http://localhost:9036/cproxydebug-15/"
+               "path/to/page.txt",1);
+    // Must have the content-bit (8) in debug, or we fake a regular OK response
+    add_request_header(pack, "Cookie",
+                "name1=value1;cproxysession=https/fakehost.com:888/100 ; name3=value3");
+    cpx->process(*pack);
+
+    YAZ_CHECK( check_response_code(pack, 302) );
+    YAZ_CHECK( check_response_header(pack, "Location",
+          "https://localhost:9036/XXX/node102/100/"
+          "https/fakehost.com:888/path/to/page.txt") );
     delete(pack);
 
     // Post request with a bad url, but with a referer header
@@ -1434,6 +1479,7 @@ void test2 (void)
       "  if(a<b)\n" // MP-486
       "  doc.write(\"<a href='http://write.com'>Click</a>\"); \n"
       "  if ( url.beginswith(\"http://\") ) ... \n"
+      "  if ( https.beginswith(\"https://\") ) ... \n"
       "  <a href=/unquoted >unquoted</a> \n"   // This should not be proxified inside a script
                                  // but may happen if the fake closing tags above are taken
                                  // for the real thing.
@@ -1497,10 +1543,12 @@ void test2 (void)
        // since we are debugging
     YAZ_CHECK( check_response_content(pack, "<h1>test page</h1>" ) );
     YAZ_CHECK( check_response_content(pack,
-      "http://localhost:9036/YYY/ZZZ/200/http/www.a5.com/staff/page.html" ) );
-    // the cproxysession cookie has the target host name, and the session number
+      "https://localhost:9036/YYY/ZZZ/200/http/www.a5.com/staff/page.html" ) );
+       // Note that we now expect all links to be proxified to https. See NOTE1 in
+       // cproxyrewrite.xml how to change that to http or automatic
+    // the cproxysession cookie has the protocol, target host name, and the session number
     YAZ_CHECK( check_response_header(pack,"Set-Cookie",
-                            "cproxysession=dummyhost.com/200; Path=/" ) );
+                            "cproxysession=http/dummyhost.com/200; Path=/" ) );
     YAZ_CHECK( check_request_header(pack,"X-MK-Component", " ") );
     YAZ_CHECK( check_response_header(pack,"X-MK-Component", " ") );
     delete(pack);
@@ -1516,47 +1564,52 @@ void test2 (void)
     YAZ_CHECK( check_response_content(pack, "<h1>test page</h1>" ) );
 
     YAZ_CHECK( check_response_content(pack, 
-                 "\'http://localhost:9036/YYY/ZZZ/200/http/www.a1.com\'" ) );
+                 "\'https://localhost:9036/YYY/ZZZ/200/http/www.a1.com\'" ) );
     YAZ_CHECK( check_response_content(pack, 
-                 "\'http://localhost:9036/YYY/ZZZ/200/http/www.a2.com/\'" ) );
+                 "\'https://localhost:9036/YYY/ZZZ/200/http/www.a2.com/\'" ) );
     
     YAZ_CHECK( check_response_content(pack, 
-                 "'http://localhost:9036/YYY/ZZZ/200/http/www.a3.com/staff'" ) );
+                 "'https://localhost:9036/YYY/ZZZ/200/http/www.a3.com/staff'" ) );
     YAZ_CHECK( check_response_content(pack, 
-                 "http://localhost:9036/YYY/ZZZ/200/http/www.a4.com/staff/" ) );
+                 "https://localhost:9036/YYY/ZZZ/200/http/www.a4.com/staff/" ) );
     YAZ_CHECK( check_response_content(pack, 
-                 "http://localhost:9036/YYY/ZZZ/200/http/www.a5.com/staff/page.html" ) );
+                 "https://localhost:9036/YYY/ZZZ/200/http/www.a5.com/staff/page.html" ) );
     YAZ_CHECK( check_response_content(pack, 
-                 "http://localhost:9036/YYY/ZZZ/200/http/doubleslash.com/a6" ) );
+                 "https://localhost:9036/YYY/ZZZ/200/http/doubleslash.com/a6" ) );
 
     YAZ_CHECK( check_response_content(pack, 
-                 "http://localhost:9036/YYY/ZZZ/200/http/www.a7.com/uppercasetag" ) );
+                 "https://localhost:9036/YYY/ZZZ/200/http/www.a7.com/uppercasetag" ) );
     YAZ_CHECK( check_response_content(pack, 
                  "ftp://ftp.indexdata.com/pub/a8/file.gz" ) );
 
     //YAZ_CHECK( check_response_content(pack, "https://secure.indexdata.com/a9/" ) );
     YAZ_CHECK( check_response_content(pack,
-                                      "http://localhost:9036/YYY/ZZZ/200/https/secure.indexdata.com/a9/" ) );
+                 "https://localhost:9036/YYY/ZZZ/200/https/secure.indexdata.com/a9/" ) );
 
     YAZ_CHECK( check_response_content(pack, 
-                 "http://localhost:9036/YYY/ZZZ/200/http/www.a10.com/path/page.html" ) );
+                 "https://localhost:9036/YYY/ZZZ/200/http/www.a10.com/path/page.html" ) );
     
     // host-relative links
-    YAZ_CHECK( check_response_content(pack, "\'http://localhost:9036/YYY/ZZZ/200/http/dummyhost.com/\'" ) );
-    YAZ_CHECK( check_response_content(pack, "\'http://localhost:9036/YYY/ZZZ/200/http/dummyhost.com/h1\'" ) );
-    YAZ_CHECK( check_response_content(pack, "\'http://localhost:9036/YYY/ZZZ/200/http/dummyhost.com/h2/page\'" ) );
-    YAZ_CHECK( check_response_content(pack, "\'http://localhost:9036/YYY/ZZZ/200/http/dummyhost.com/h3/page/\'" ) );
-    YAZ_CHECK( check_response_content(pack, "\'http://localhost:9036/YYY/ZZZ/200/http/dummyhost.com/h4/page.html\'" ) );
+    YAZ_CHECK( check_response_content(pack,
+                "\'https://localhost:9036/YYY/ZZZ/200/http/dummyhost.com/\'" ) );
+    YAZ_CHECK( check_response_content(pack,
+                "\'https://localhost:9036/YYY/ZZZ/200/http/dummyhost.com/h1\'" ) );
+    YAZ_CHECK( check_response_content(pack,
+                "\'https://localhost:9036/YYY/ZZZ/200/http/dummyhost.com/h2/page\'" ) );
+    YAZ_CHECK( check_response_content(pack,
+                "\'https://localhost:9036/YYY/ZZZ/200/http/dummyhost.com/h3/page/\'" ) );
+    YAZ_CHECK( check_response_content(pack,
+               "\'https://localhost:9036/YYY/ZZZ/200/http/dummyhost.com/h4/page.html\'" ) );
 
     // Check that the links in the text content are not changed
     YAZ_CHECK( check_response_content(pack, "http://www.p1.com " ) );
     YAZ_CHECK( check_response_content(pack, "http://www.p2.com/staff/page.html" ) );
 
     YAZ_CHECK( check_response_content(pack,
-           "url1=\"http://localhost:9036/YYY/ZZZ/200/http/url1.in.script\"" ) );
+               "url1=\"https://localhost:9036/YYY/ZZZ/200/http/url1.in.script\"" ) );
 
     YAZ_CHECK( check_response_content(pack,
-           "url3=\"http://localhost:9036/YYY/ZZZ/200/http/url3.in.script/page\"" ) );
+               "url3=\"https://localhost:9036/YYY/ZZZ/200/http/url3.in.script/page\"" ) );
 
     // We can not proxify host-relative links, any string that starts with a '/'
     // would look like one, and could be something totally different, like an XPath
@@ -1566,13 +1619,19 @@ void test2 (void)
     YAZ_CHECK( check_response_content(pack, "hostrel4=\"/hr4/page/\"" ) );
     YAZ_CHECK( check_response_content(pack, "hostrel5=\"/hr5/page.html\"" ) );
     
-    YAZ_CHECK( check_response_content(pack, "http://unquoted.com" ) );
-    YAZ_CHECK( check_response_content(pack, "http://localhost:9036/YYY/ZZZ/200/http/singlequoted.com" ) );
-    YAZ_CHECK( check_response_content(pack, "http://localhost:9036/YYY/ZZZ/200/http/doublequoted.com" ) );
-    YAZ_CHECK( check_response_content(pack, "http://localhost:9036/YYY/ZZZ/200/http/mixedquoted1.com" ) );
-    YAZ_CHECK( check_response_content(pack, "http://localhost:9036/YYY/ZZZ/200/http/mixedquoted2.com" ) );
+    YAZ_CHECK( check_response_content(pack,
+                "http://unquoted.com" ) );
+    YAZ_CHECK( check_response_content(pack,
+                "https://localhost:9036/YYY/ZZZ/200/http/singlequoted.com" ) );
+    YAZ_CHECK( check_response_content(pack,
+                "https://localhost:9036/YYY/ZZZ/200/http/doublequoted.com" ) );
+    YAZ_CHECK( check_response_content(pack,
+                "https://localhost:9036/YYY/ZZZ/200/http/mixedquoted1.com" ) );
+    YAZ_CHECK( check_response_content(pack,
+                "https://localhost:9036/YYY/ZZZ/200/http/mixedquoted2.com" ) );
     YAZ_CHECK( check_response_content(pack, "http://outcommented.com" ) );
-    YAZ_CHECK( check_response_content(pack, "http://localhost:9036/YYY/ZZZ/200/http/write.com" ) );
+    YAZ_CHECK( check_response_content(pack,
+                "https://localhost:9036/YYY/ZZZ/200/http/write.com" ) );
       // See MP-486
     YAZ_CHECK( check_response_content(pack, "if(a<b)" ) );
     YAZ_CHECK( check_response_content(pack, "document.write(\"</script\" + \">\")" ) );
@@ -1584,15 +1643,17 @@ void test2 (void)
     YAZ_CHECK( check_response_content(pack, "<a href=/unquoted >unquoted</a>" ) );
 
     YAZ_CHECK( check_response_content(pack,
-        "onclick=\"window.location='http://localhost:9036/YYY/ZZZ/200/http/first.com';" ) );
+        "onclick=\"window.location='https://localhost:9036/YYY/ZZZ/200/http/first.com';" ) );
     YAZ_CHECK( check_response_content(pack,
-        "onclick=\'window.location=\"http://localhost:9036/YYY/ZZZ/200/http/second.com\";" ) );
+        "onclick=\'window.location=\"https://localhost:9036/YYY/ZZZ/200/http/second.com\";" ) );
 
     // test for CPXY-47, require at least something in the host portion
     // Have seen such construct in real life.
     YAZ_CHECK( check_response_content(pack,
         "if ( url.beginswith(\"http://\") ) " ) );
-    
+    YAZ_CHECK( check_response_content(pack,
+        "if ( https.beginswith(\"https://\") ) " ) );
+
     // Simple custom replacement with a space in both strings
     YAZ_CHECK( check_response_content(pack,
         "This line might be repaired by the") );
@@ -1717,10 +1778,10 @@ void test2 (void)
     // Link headers are special, they have <>'s around the URL, and thus need
     // their own rules.
     YAZ_CHECK( check_response_header(pack,"Link",
-                 "<http://localhost:9036/YYY/ZZZ/200/http/see.also.com/absolute/>;") );
+            "<https://localhost:9036/YYY/ZZZ/200/http/see.also.com/absolute/>;") );
     YAZ_CHECK( check_any_response_header(pack,"Link", "<relative/path/>;"));
     YAZ_CHECK( check_any_response_header(pack,"Link",
-      "<http://localhost:9036/YYY/ZZZ/200/sub.dummydomain.com/host/relative/>;") );
+            "<https://localhost:9036/YYY/ZZZ/200/sub.dummydomain.com/host/relative/>;") );
       // The Link header needs a special regexp, as it has a funny format, with
       // the URL inside angle brackets. Need to write that. TODO!
     YAZ_CHECK( check_response_header(pack,"X-Do-Not-Look",
@@ -1873,7 +1934,7 @@ void test2 (void)
     YAZ_CHECK( check_response_code(pack, 301) );
     YAZ_CHECK( check_no_response_header(pack,"Content-Type") );
     YAZ_CHECK( check_response_header(pack,"Location", 
-                   "http://localhost:9036/YYY/ZZZ/200/http/www.newlocation.com/") );
+                   "https://localhost:9036/YYY/ZZZ/200/http/www.newlocation.com/") );
     delete(pack);
 
     std::string movedpage2 =
@@ -1894,7 +1955,7 @@ void test2 (void)
     YAZ_CHECK( check_response_code(pack, 302) );
     YAZ_CHECK( check_no_response_header(pack,"Content-Type") );
     YAZ_CHECK( check_response_header(pack,"Location",
-                "http://localhost:9036/YYY/ZZZ/200/http/"
+                "https://localhost:9036/YYY/ZZZ/200/http/"
                 "dummyhost.com/host/relative/link?with=params") );
     delete(pack);
 
